==> amarok-1.86.tar.bz2: amarok-1.86/src/context/popupdropper/PopupDropper_Export.h <==
/***************************************************************************
 *   Copyright (c) 2008  Jeff Mitchell <mitchell@kde.org>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef POPUPDROPPER_EXPORT_H
#define POPUPDROPPER_EXPORT_H

#if defined(_WIN32) || defined(_WIN64)
    #define POPUPDROPPER_EXPORT __declspec(dllexport)
#else
    #define POPUPDROPPER_EXPORT __attribute__ ((visibility("default")))
#endif

#endif

==> amarok-1.94.tar.bz2: amarok-1.94/src/context/popupdropper/PopupDropper_Export.h <==
/***************************************************************************
 *   Copyright (c) 2008  Jeff Mitchell <mitchell@kde.org>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef POPUPDROPPER_EXPORT_H
#define POPUPDROPPER_EXPORT_H

#include <qglobal.h>

#ifdef Q_WS_WIN
# if defined(MAKE_POPUPDROPPER_LIB)
#  define POPUPDROPPER_EXPORT Q_DECL_EXPORT
# else
#  define POPUPDROPPER_EXPORT Q_DECL_IMPORT
# endif
#else
# define POPUPDROPPER_EXPORT Q_DECL_EXPORT
#endif 

#endif
